aboutsummaryrefslogtreecommitdiffstats
path: root/src/java/org
diff options
context:
space:
mode:
authorJeremias Maerki <jeremias@apache.org>2011-05-05 15:50:20 +0000
committerJeremias Maerki <jeremias@apache.org>2011-05-05 15:50:20 +0000
commit173181b3bdd6f4d6ae1e17f0d8ccc717551aaf89 (patch)
treea7b3a0719149f99177a6a7b64023166e543d0d42 /src/java/org
parent7aed9feb97b764ff13d065b66854b897b18ec881 (diff)
downloadxmlgraphics-fop-173181b3bdd6f4d6ae1e17f0d8ccc717551aaf89.tar.gz
xmlgraphics-fop-173181b3bdd6f4d6ae1e17f0d8ccc717551aaf89.zip
Bugzilla #51144:
Removed invalid entries in ToUnicode table of CID subset fonts. Submitted by: Mehdi Houshmand <med1985.at.gmail.com> git-svn-id: https://svn.apache.org/repos/asf/xmlgraphics/fop/trunk@1099852 13f79535-47bb-0310-9956-ffa450edef68
Diffstat (limited to 'src/java/org')
-rw-r--r--src/java/org/apache/fop/fonts/CIDSubset.java11
-rw-r--r--src/java/org/apache/fop/fonts/MultiByteFont.java3
2 files changed, 3 insertions, 11 deletions
diff --git a/src/java/org/apache/fop/fonts/MultiByteFont.java b/src/java/org/apache/fop/fonts/MultiByteFont.java
index afac21c1b..629bfa1b7 100644
--- a/src/java/org/apache/fop/fonts/MultiByteFont.java
+++ b/src/java/org/apache/fop/fonts/MultiByteFont.java
@@ -48,8 +48,7 @@ public class MultiByteFont extends CIDFont {
* Default constructor
*/
public MultiByteFont() {
- // Make sure that the 3 first glyphs are included
- subset.setupFirstThreeGlyphs();
+ subset.setupFirstGlyph();
// Create a quasiunique prefix for fontname
synchronized (this.getClass()) {
diff --git a/src/java/org/apache/fop/fonts/CIDSubset.java b/src/java/org/apache/fop/fonts/CIDSubset.java
index b152ad38e..712d8a73b 100644
--- a/src/java/org/apache/fop/fonts/CIDSubset.java
+++ b/src/java/org/apache/fop/fonts/CIDSubset.java
@@ -62,19 +62,12 @@ public class CIDSubset {
}
/**
* Adds the initial 3 glyphs which are the same for all CID subsets.
*/
- public void setupFirstThreeGlyphs() {
- // Make sure that the 3 first glyphs are included
+ public void setupFirstGlyph() {
usedGlyphs.put(new Integer(0), new Integer(0));
usedGlyphsIndex.put(new Integer(0), new Integer(0));
usedGlyphsCount++;
- usedGlyphs.put(new Integer(1), new Integer(1));
- usedGlyphsIndex.put(new Integer(1), new Integer(1));
- usedGlyphsCount++;
- usedGlyphs.put(new Integer(2), new Integer(2));
- usedGlyphsIndex.put(new Integer(2), new Integer(2));
- usedGlyphsCount++;
}
/**
@@ -62,19 +62,12 @@ public class CIDSubset {
}
/**
- * Adds the initial 3 glyphs which are the same for all CID subsets.
+ * Adds the first glyph which is reserved for .notdef for all CID subsets.
*/